@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2017-2019 Montel Laurent <montel@kde.org>
+  Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,9 +18,9 @@
 #ifndef JOBTRACKERFILTERPROXYMODEL_H
 #define JOBTRACKERFILTERPROXYMODEL_H
 
-#include <KRecursiveFilterProxyModel>
+#include <QSortFilterProxyModel>
 
-class JobTrackerFilterProxyModel : public KRecursiveFilterProxyModel
+class JobTrackerFilterProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
 public:
@@ -32,7 +32,7 @@ public:
     void setShowOnlyFailed(bool showOnlyFailed);
 
 protected:
-    bool acceptRow(int source_row, const QModelIndex &source_parent) const override;
+    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
 
 private:
     int mSearchColumn;
