@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2017-2019 Montel Laurent <montel@kde.org>
+  Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -53,7 +53,11 @@ JobTrackerSearchWidget::JobTrackerSearchWidget(QWidget *parent)
     mSelectColumn->addItem(QStringLiteral("Job Type"), 4);
     mSelectColumn->addItem(QStringLiteral("State"), 5);
     mSelectColumn->addItem(QStringLiteral("Info"), 6);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(mSelectColumn, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &JobTrackerSearchWidget::slotColumnChanged);
+#else
+    connect(mSelectColumn, QOverload<int, const QString &>::of(&QComboBox::currentIndexChanged), this, &JobTrackerSearchWidget::slotColumnChanged);
+#endif
 }
 
 JobTrackerSearchWidget::~JobTrackerSearchWidget()
